pycocoa.runtime.ObjCClassMethod

Package pycocoa :: Module runtime :: Class ObjCClassMethod |
[frames] | no frames]

# Class ObjCClassMethod

              object --+
                       |
    internals._Objectype --+
                           |
                   _ObjCBase --+
                               |
                      ObjCMethod --+
                                   |
                                  ObjCClassMethod

Python class representing an unbound ObjC class method, only to distinguish class methods from instance methods.

Instance Methods
Inherited from `ObjCMethod`: `__call__`, `__init__`, `__str__` Inherited from `_ObjCBase`: `__repr__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `ObjCMethod`: `argtypes`, `encoding`, `name`, `restype` Inherited from `_ObjCBase`: `description` Inherited from `internals._Objectype`: `typename` Inherited from `object`: `__class__`